helper function for hmde_data_template that provides data structure for model, Also used to guide the user on the required structure for the model they want.
Source:R/hmde_model.R
hmde_model.Rdhelper function for hmde_data_template that provides data structure for model, Also used to guide the user on the required structure for the model they want.